@@ -62,6 +62,10 @@ class AlthermaUnitController:
         self._unit.init_unit()
         self._function = function
 
+    @property
+    def unit(self):
+        return self._unit
+
     async def read(self, query_type, prop):
         destination = f'{self._dest}/{query_type}/{prop}/la'
         result = await self._connection.request(destination)
